@@ -1,10 +1,8 @@
 _base_ = ['./fcos.py', './coco_detection.py', 'configs/base.py']
 
 log_config = dict(
-    interval=50,
-    hooks=[
+    interval=50, hooks=[
         dict(type='TextLoggerHook'),
-        # dict(type='TensorboardLoggerHook')
     ])
 
 checkpoint_config = dict(interval=10)
