@@ -10,6 +10,58 @@ from easycv.core.evaluation.top_down_eval import keypoints_from_heatmaps
 from easycv.framework.errors import ValueError
 
 
+def decode_heatmap(heatmaps, img_metas, test_cfg):
+    batch_size = len(img_metas)
+
+    if 'bbox_id' in img_metas[0]:
+        bbox_ids = []
+    else:
+        bbox_ids = None
+
+    c = np.zeros((batch_size, 2), dtype=np.float32)
+    s = np.zeros((batch_size, 2), dtype=np.float32)
+    image_ids = []
+    score = np.ones(batch_size)
+    for i in range(batch_size):
+        c[i, :] = img_metas[i]['center']
+        s[i, :] = img_metas[i]['scale']
+        image_ids.append(img_metas[i]['image_id'])
+
+        if 'bbox_score' in img_metas[i]:
+            score[i] = np.array(img_metas[i]['bbox_score']).reshape(-1)
+        if bbox_ids is not None:
+            bbox_ids.append(img_metas[i]['bbox_id'])
+
+    preds, maxvals = keypoints_from_heatmaps(
+        heatmaps,
+        c,
+        s,
+        unbiased=test_cfg.get('unbiased_decoding', False),
+        post_process=test_cfg.get('post_process', 'default'),
+        kernel=test_cfg.get('modulate_kernel', 11),
+        valid_radius_factor=test_cfg.get('valid_radius_factor', 0.0546875),
+        use_udp=test_cfg.get('use_udp', False),
+        target_type=test_cfg.get('target_type', 'GaussianHeatmap'))
+
+    all_preds = np.zeros((batch_size, preds.shape[1], 3), dtype=np.float32)
+    all_boxes = np.zeros((batch_size, 6), dtype=np.float32)
+    all_preds[:, :, 0:2] = preds[:, :, 0:2]
+    all_preds[:, :, 2:3] = maxvals
+    all_boxes[:, 0:2] = c[:, 0:2]
+    all_boxes[:, 2:4] = s[:, 0:2]
+    all_boxes[:, 4] = np.prod(s * 200.0, axis=1)
+    all_boxes[:, 5] = score
+
+    result = {}
+
+    result['preds'] = all_preds
+    result['boxes'] = all_boxes
+    result['image_ids'] = image_ids
+    result['bbox_ids'] = bbox_ids
+
+    return result
+
+
 class TopdownHeatmapBaseHead(nn.Module):
     """Base class for top-down heatmap heads.
 
@@ -53,56 +105,7 @@ class TopdownHeatmapBaseHead(nn.Module):
                 - "bbox_score": score of bbox
             output (np.ndarray[N, K, H, W]): model predicted heatmaps.
         """
-        batch_size = len(img_metas)
-
-        if 'bbox_id' in img_metas[0]:
-            bbox_ids = []
-        else:
-            bbox_ids = None
-
-        c = np.zeros((batch_size, 2), dtype=np.float32)
-        s = np.zeros((batch_size, 2), dtype=np.float32)
-        image_ids = []
-        score = np.ones(batch_size)
-        for i in range(batch_size):
-            c[i, :] = img_metas[i]['center']
-            s[i, :] = img_metas[i]['scale']
-            image_ids.append(img_metas[i]['image_id'])
-
-            if 'bbox_score' in img_metas[i]:
-                score[i] = np.array(img_metas[i]['bbox_score']).reshape(-1)
-            if bbox_ids is not None:
-                bbox_ids.append(img_metas[i]['bbox_id'])
-
-        preds, maxvals = keypoints_from_heatmaps(
-            output,
-            c,
-            s,
-            unbiased=self.test_cfg.get('unbiased_decoding', False),
-            post_process=self.test_cfg.get('post_process', 'default'),
-            kernel=self.test_cfg.get('modulate_kernel', 11),
-            valid_radius_factor=self.test_cfg.get('valid_radius_factor',
-                                                  0.0546875),
-            use_udp=self.test_cfg.get('use_udp', False),
-            target_type=self.test_cfg.get('target_type', 'GaussianHeatmap'))
-
-        all_preds = np.zeros((batch_size, preds.shape[1], 3), dtype=np.float32)
-        all_boxes = np.zeros((batch_size, 6), dtype=np.float32)
-        all_preds[:, :, 0:2] = preds[:, :, 0:2]
-        all_preds[:, :, 2:3] = maxvals
-        all_boxes[:, 0:2] = c[:, 0:2]
-        all_boxes[:, 2:4] = s[:, 0:2]
-        all_boxes[:, 4] = np.prod(s * 200.0, axis=1)
-        all_boxes[:, 5] = score
-
-        result = {}
-
-        result['preds'] = all_preds
-        result['boxes'] = all_boxes
-        result['image_ids'] = image_ids
-        result['bbox_ids'] = bbox_ids
-
-        return result
+        return decode_heatmap(output, img_metas, self.test_cfg)
 
     @staticmethod
     def _get_deconv_cfg(deconv_kernel):
