@@ -1,4 +1,6 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
-CACHE_DIR = '.easycv_cache'
+import os
+
+CACHE_DIR = os.path.expanduser('~/.cache/easycv/')
 
 MAX_READ_IMAGE_TRY_TIMES = 10
